@@ -23,10 +23,12 @@ class Storage(driver.Base):
         self._secret_key = config.jss_secretkey
         self._bucket = config.jss_bucket
         self._domain = config.jss_domain
+        self._rootpath = path if path[0] != '/' else path[1:]
         logger.info("==========================>access_key:%s" % config.jss_accesskey)
         logger.info("==========================>jss_secretkey:%s" % config.jss_secretkey)
         logger.info("==========================>jss_bucket:%s" % config.jss_bucket)
         logger.info("==========================>jss_domain:%s" % config.jss_domain)
+        logger.info("==========================>rootpath:%s" % self._rootpath)
         
         self._jss = JssClient(self._access_key, self._secret_key, self._domain, None)
         
